@@ -1,5 +1,6 @@
 """Models for the ``cmsplugin_blog_categories`` app."""
 from django.db import models
+from django.utils import timezone
 from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 
@@ -25,6 +26,14 @@ class Category(models.Model):
     def __unicode__(self):
         return self.get_title()
 
+    def get_entries(self):
+        """Returns the entries for this category."""
+        qs = EntryCategory.objects.select_related()
+        qs = qs.filter(category=self, entry__is_published=True,
+            entry__pub_date__lte=timezone.now())
+        qs = qs.order_by('-entry__pub_date')
+        return [item.entry for item in qs]
+
     @models.permalink
     def get_absolute_url(self):
         return ('blog_archive_category', (), {'category': self.slug, })
